@@ -8,14 +8,10 @@
 package diskimage
 
 import (
-	"bufio"
-	"errors"
 	"fmt"
 	"io/ioutil"
 	"os"
-	"os/exec"
 	"path/filepath"
-	"strings"
 	"text/template"
 
 	"launchpad.net/goget-ubuntu-touch/sysutils"
@@ -34,14 +30,7 @@ import (
 // with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 type CoreUBootImage struct {
-	CoreImage
-	SystemImage
-	hardware  HardwareDescription
-	oem       OemDescription
-	location  string
-	size      int64
-	baseMount string
-	parts     []partition
+	BaseImage
 }
 
 const snappySystemTemplate = `# This is a snappy variables and boot logic file and is entirely generated and
@@ -79,46 +68,16 @@ type FlashInstructions struct {
 
 func NewCoreUBootImage(location string, size int64, hw HardwareDescription, oem OemDescription) *CoreUBootImage {
 	return &CoreUBootImage{
-		hardware: hw,
-		oem:      oem,
-		location: location,
-		size:     size,
+		BaseImage{
+			hardware:  hw,
+			oem:       oem,
+			location:  location,
+			size:      size,
+			partCount: 4,
+		},
 	}
 }
 
-func (img *CoreUBootImage) Mount() error {
-	baseMount, err := mount(img.parts)
-	if err != nil {
-		return err
-	}
-	img.baseMount = baseMount
-
-	return nil
-}
-
-func (img *CoreUBootImage) Unmount() (err error) {
-	if img.baseMount == "" {
-		panic("No base mountpoint set")
-	}
-	defer func() {
-		os.Remove(img.baseMount)
-		img.baseMount = ""
-	}()
-
-	if out, err := exec.Command("sync").CombinedOutput(); err != nil {
-		return fmt.Errorf("Failed to sync filesystems before unmounting: %s", out)
-	}
-
-	for _, part := range img.parts {
-		mountpoint := filepath.Join(img.baseMount, string(part.dir))
-		if out, err := exec.Command("umount", mountpoint).CombinedOutput(); err != nil {
-			panic(fmt.Sprintf("unable to unmount dir for image: %s", out))
-		}
-	}
-
-	return nil
-}
-
 //Partition creates a partitioned image from an img
 func (img *CoreUBootImage) Partition() error {
 	if err := sysutils.CreateEmptyFile(img.location, img.size, sysutils.GB); err != nil {
@@ -142,137 +101,6 @@ func (img *CoreUBootImage) Partition() error {
 	return parted.create(img.location)
 }
 
-//Map creates loop devices for the partitions
-func (img *CoreUBootImage) Map() error {
-	if isMapped(img.parts) {
-		panic("cannot double map partitions")
-	}
-
-	kpartxCmd := exec.Command("kpartx", "-avs", img.location)
-	stdout, err := kpartxCmd.StdoutPipe()
-	if err != nil {
-		return err
-	}
-
-	if err := kpartxCmd.Start(); err != nil {
-		return err
-	}
-
-	loops := make([]string, 0, 4)
-	scanner := bufio.NewScanner(stdout)
-	for scanner.Scan() {
-		fields := strings.Fields(scanner.Text())
-
-		if len(fields) > 2 {
-			loops = append(loops, fields[2])
-		} else {
-			return errors.New("issues while determining drive mappings")
-		}
-	}
-	if err := scanner.Err(); err != nil {
-		return err
-	}
-
-	// there are 5 partitions, so there should be five loop mounts
-	if len(loops) != 4 {
-		return errors.New("more partitions then expected while creating loop mapping")
-	}
-
-	mapPartitions(img.parts, loops)
-
-	if err := kpartxCmd.Wait(); err != nil {
-		return err
-	}
-
-	return nil
-}
-
-//Unmap destroys loop devices for the partitions
-func (img *CoreUBootImage) Unmap() error {
-	if img.baseMount != "" {
-		panic("cannot unmap mounted partitions")
-	}
-
-	for _, part := range img.parts {
-		if err := exec.Command("dmsetup", "clear", part.loop).Run(); err != nil {
-			return err
-		}
-	}
-
-	if err := exec.Command("kpartx", "-d", img.location).Run(); err != nil {
-		return err
-	}
-
-	unmapPartitions(img.parts)
-
-	return nil
-}
-
-func (img CoreUBootImage) Format() error {
-	for _, part := range img.parts {
-		dev := filepath.Join("/dev/mapper", part.loop)
-
-		if part.fs == fsFat32 {
-			cmd := []string{"-F", "32", "-n", string(part.label)}
-
-			size, err := sectorSize(dev)
-			if err != nil {
-				return err
-			}
-
-			if size != "512" {
-				cmd = append(cmd, "-s", "1")
-			}
-
-			cmd = append(cmd, "-S", size, dev)
-
-			if out, err := exec.Command("mkfs.vfat", cmd...).CombinedOutput(); err != nil {
-				return fmt.Errorf("unable to create filesystem: %s", out)
-			}
-		} else {
-			if out, err := exec.Command("mkfs.ext4", "-F", "-L", string(part.label), dev).CombinedOutput(); err != nil {
-				return fmt.Errorf("unable to create filesystem: %s", out)
-			}
-		}
-	}
-
-	return nil
-}
-
-// User returns the writable path
-func (img *CoreUBootImage) Writable() string {
-	if img.parts == nil {
-		panic("img is not setup with partitions")
-	}
-
-	if img.baseMount == "" {
-		panic("img not mounted")
-	}
-
-	return filepath.Join(img.baseMount, string(writableDir))
-}
-
-//System returns the system path
-func (img *CoreUBootImage) System() string {
-	if img.parts == nil {
-		panic("img is not setup with partitions")
-	}
-
-	if img.baseMount == "" {
-		panic("img not mounted")
-	}
-
-	return filepath.Join(img.baseMount, string(systemADir))
-}
-
-func (img CoreUBootImage) BaseMount() string {
-	if img.baseMount == "" {
-		panic("image needs to be mounted")
-	}
-
-	return img.baseMount
-}
-
 func (img CoreUBootImage) SetupBoot(oemRootPath string) error {
 	// destinations
 	bootPath := filepath.Join(img.baseMount, string(bootDir))
